package info.textgrid.middleware;

import java.util.ArrayList;
import java.util.List;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.http.HttpHost;
import org.elasticsearch.client.RestClient;
import org.elasticsearch.client.RestHighLevelClient;

/**
 * <p>
 * Establishing to connection to an ElasticSearch client.
 * </p>
 * 
 * @author Maximilian Brodhun, SUB Göttingen
 * @author Stefan E. Funk, SUB Göttingen
 * @version 2019-10-30
 * @since 2014-01-09
 */
public class OAI_ESClient {

  private Log log = LogFactory.getLog(OAI_ESClient.class);
  private static String url;
  private static int[] ports;
  private static String esCluster;
  private static String esIndex;
  private static String esType;
  private static RestHighLevelClient esClient;

  /**
   * Constructor for the connection to an ElasticSearch index
   * 
   * @param url address for the ELasticSearch connection
   * @param port for the ElasticSearch connection
   * @param clusterName indicating the name of the cluster where the index exists
   */

  public OAI_ESClient(String url, int[] ports, int itemLimit) {

    // int port = Integer.parseInt(thePort);

    /*
     * this.log.info("ElasticSearch connection settings:"); this.log.info("url = " + url);
     * this.log.info("port = " + port); this.log.info("cluster name = " + clusterName);
     */

    OAI_ESClient.setUrl(url);

    OAI_ESClient.setPorts(ports);


    List<HttpHost> hosts = new ArrayList<HttpHost>();
    for (int port : ports) {
      hosts.add(new HttpHost(url, port, "http"));
    }

    setEsClient(new RestHighLevelClient(
        RestClient.builder(
            hosts.toArray(new HttpHost[hosts.size()]))));

    this.log.info(
        "ElasticSearchClient started with settings: " + url + " ," + ports.toString() + " http");
  }

  /**
   * 
   * @return esIndex
   */
  public static String getEsIndex() {
    return esIndex;
  }

  /**
   * 
   * @param esIndex
   */
  public static void setEsIndex(String esIndex) {
    OAI_ESClient.esIndex = esIndex;
  }

  /**
   * 
   * @return esType
   */
  public static String getEsType() {
    return esType;
  }

  /**
   * 
   * @param esType
   */
  public static void setEsType(String esType) {
    OAI_ESClient.esType = esType;
  }



  /**
   * 
   * @return esCluster
   */
  public static String getClusterName() {
    return esCluster;
  }

  /**
   * 
   * @param esCluster
   */
  public static void setClusterName(String esCluster) {
    OAI_ESClient.esCluster = esCluster;
  }

  /**
   * 
   * @return url
   */
  public static String getUrl() {
    return url;
  }

  /**
   * 
   * @param url
   */
  public static void setUrl(String url) {
    OAI_ESClient.url = url;
  }

  /**
   * 
   * @return port
   */
  public static int[] getPort() {
    return ports;
  }

  /**
   * 
   * @param port
   */
  public static void setPorts(int ports[]) {
    OAI_ESClient.ports = ports;
  }

  /**
   * 
   * @param oaiClient
   */
  public static void setOaiESClient(RestHighLevelClient theOaiClient) {
    OAI_ESClient.esClient = theOaiClient;
  }

  /**
   * @return
   */
  public static RestHighLevelClient getEsClient() {
    return esClient;
  }

  /**
   * @param esClient
   */
  public static void setEsClient(RestHighLevelClient esClient) {
    OAI_ESClient.esClient = esClient;
  }

}
